@@ -22,7 +22,8 @@ class RegisterAck:
 
 
 # 登录信息
-@aztdataclass(proto.LoginInfo, adj_time=dict(exchange_time="%Y%m%d%H%M%S"))
+# @aztdataclass(proto.LoginInfo, adj_time=dict(exchange_time="%Y%m%d-%H:%M:%S.%f"))
+@aztdataclass(proto.LoginInfo, adj_time=dict(exchange_time=["%Y%m%d%H%M%S", "%Y%m%d-%H:%M:%S.%f"]))
 class LoginInfo:
     account: str = None
     trading_day: str = None
@@ -67,7 +68,8 @@ class AccDepositAck:
 
 @aztdataclass(proto.OrdStatusMsg, price_dec="price_decimal_place",
               adj_price=["traded_amount", "total_fee", "frozen_margin", "frozen_price"],
-              adj_time=dict(report_time="%Y%m%d-%H%M%S.%f"))
+              adj_time=dict(report_time=["%Y%m%d-%H:%M:%S.%f", "%Y%m%d-%H%M%S.%f"]),
+              )
 class OrdStatusMsg:
     order_status: int = None
     traded_qty: int = None
@@ -94,7 +96,7 @@ class QueryOrdersAck:
 
 # 成交回报信息
 @aztdataclass(proto.TradeReport, price_dec="price_decimal_place", adj_price=["traded_price", "fee"],
-              adj_time=dict(transact_time="%Y%m%d-%H:%M:%S"))
+              adj_time=dict(transact_time=["%Y%m%d-%H:%M:%S.%f","%Y%m%d-%H:%M:%S"]))
 class TradeReport:
     order_id: str = None
     client_ref: str = None
@@ -129,6 +131,7 @@ class StockPosition:
     frozen_qty: int = None
     # update_time: datetime.datetime = None
 
+
 # 持仓查询回复信息
 @aztdataclass(proto.QueryPositionsAck, adj_repeat=["positions"])
 class QueryPositionsAck:
@@ -136,7 +139,7 @@ class QueryPositionsAck:
 
 
 # 撤单拒绝回报
-@aztdataclass(proto.CancelOrderReject, adj_time=dict(report_time="%Y%m%d%H%M%S"))
+@aztdataclass(proto.CancelOrderReject, adj_time=dict(report_time="%Y%m%d-%H:%M:%S.%f"))
 class CancelOrderReject:
     client_ref: str = None
     org_order_id: str = None
