@@ -1,6 +1,6 @@
 import dataclasses
 import datetime
-from . import azt_errors
+from . import azt_errors, azt_logger
 
 
 def _verify_params(param, verify_type, default=None):
@@ -128,7 +128,22 @@ def aztdataclass(protocls,
                 proto_time_attr_val: str = getattr(proto, time_attr_name)
                 if proto_time_attr_val != "":
                     time_format = adj_time[time_attr_name]
-                    params[time_attr_name] = datetime.datetime.strptime(proto_time_attr_val, time_format)
+                    if type(time_format) is str:
+                        time_format = [time_format]
+                    time_transformed = None
+                    tf_error = ValueError
+                    for t_format in time_format:
+                        try:
+                            time_transformed = datetime.datetime.strptime(proto_time_attr_val, t_format)
+                            break
+                        except ValueError as val_error:
+                            tf_error = val_error
+                            continue
+                    if time_transformed is None:
+                        azt_logger.error(f"{time_attr_name}时间格式转换错误！")
+                        raise tf_error
+                    # time_transformed = datetime.datetime.strptime(proto_time_attr_val, time_format)
+                    params[time_attr_name] = time_transformed
         return cls(**params)
 
     # # todo py转proto方法 未完待续...
@@ -202,6 +217,8 @@ def aztdataclass(protocls,
                     continue
                 if isinstance(time_attr_val, datetime.datetime):
                     time_format = adj_time[time_attr_name]
+                    if type(time_format) is list:
+                        time_format = time_format[0]
                     setattr(proto, time_attr_name, time_attr_val.strftime(time_format))
                 elif isinstance(time_attr_val, str):
                     setattr(proto, time_attr_name, time_attr_val)
@@ -209,7 +226,6 @@ def aztdataclass(protocls,
                     raise azt_errors.DatetimeTypeError
         return proto
 
-
     def wrapper_func(pycls):
         if not hasattr(pycls, "__proto2py__"):
             setattr(pycls, "__proto2py__", classmethod(func_proto2py))
