@@ -94,28 +94,17 @@ class AztVeApi:
 
     def __init__(self):
         self.__api = AztVeApiOld()
-        # self.__api.RegisterSpi(_SpiApdapter)
         self.__account = None
 
     # 初始化
-    def Init(self, server_addr: str, spi=None):
+    def Init(self, server_addr: str, spi=None, hb_times: int = 3, hb_interval: int = 5):
         _spi = _SpiApdapter()
         if spi is not None:
             if spi.__class__ is type:
                 spi = spi()
             _spi.register_new_spi(spi)
 
-        self.__api.Init(server_addr, _spi)
-
-    # # 注册Spi
-    # def RegisterSpi(self, spi):
-    #     if spi.__class__ is type:
-    #         spi = spi()
-    #     if hasattr(self.__api.spi, "register_new_spi"):
-    #         spi.api = self
-    #         self.__api.spi.register_new_spi(spi)
-    #     else:
-    #         self.__api.RegisterSpi(spi)
+        return self.__api.Init(server_addr, _spi, hb_times, hb_interval)
 
     # 注册账户
     def RegisterAccount(self, strategy_id: str, strategy_check_code: str, sync: bool = False, timeout: int = None):
@@ -125,10 +114,6 @@ class AztVeApi:
         )
         return self.__api.RegisterReq(register_req, sync, timeout)
 
-    # #
-    # def log(self, *msgs):
-    #     self.__api.log(*msgs)
-
     # 登录
     def Login(self, account: str, passwd: str, sync: bool = False, timeout: int = None):
         self.__account = account
@@ -165,10 +150,10 @@ class AztVeApi:
         return self.__api.TradingAccQryReq(trade_req, sync, timeout)
 
     # 查询订单信息
-    def QueryOrders(self, market: str = None, code: str = None, order_id: str = None, unfinished: bool = False,
-                    sync: bool = False, timeout: int = None):
+    def QueryOrders(self, market: str = None, code: str = None, client_ref: str = None, order_id: str = None,
+                    unfinished: bool = False, sync: bool = False, timeout: int = None):
         order_req = api_struct.QueryOrdersReq(account=self.__account, market=market, code=code, order_id=order_id,
-                                              unfinished=unfinished)
+                                              unfinished=unfinished, client_ref=client_ref)
         return self.__api.QueryOrdersReq(order_req, sync, timeout)
 
     # 查询交易信息
@@ -197,8 +182,8 @@ class AztVeApi:
                                                              start_time=start_time, end_time=end_time)
         return self.__api.QueryHistoryTradesReq(historytrades_req, sync, timeout)
 
-    def InsertOrder(self, market: str, code: str, order_type: int, order_side: int, effect: int,
-                    order_price: float, order_qty: int, discretion_price: float):
+    def _insert_order(self, market: str, code: str, order_type: int, order_side: int, effect: int,
+                      order_price: float, order_qty: int, discretion_price: float):
         order_req = api_struct.PlaceOrder(
             account=self.__account,
             market=market,
@@ -221,8 +206,8 @@ class AztVeApi:
             order_price: float = None,  # 委托限价,适用于限价单,保留两位小数
             discretion_price: float = None  # 市价转限价后委托限价,适用于市价转限价委托,保留两位小数
             ):
-        self.InsertOrder(market, code, order_type, EnumProto.KOrderDirection_Buy, effect, order_price, order_qty,
-                         discretion_price)
+        self._insert_order(market, code, order_type, EnumProto.KOrderDirection_Buy, effect, order_price, order_qty,
+                           discretion_price)
 
     # 卖出委托
     def Sell(self, market: str, code: str,
@@ -232,8 +217,8 @@ class AztVeApi:
              order_price: float = None,  # 委托限价,适用于限价单,保留两位小数
              discretion_price: float = None  # 市价转限价后委托限价,适用于市价转限价委托,保留两位小数
              ):
-        self.InsertOrder(market, code, order_type, EnumProto.KOrderDirection_Buy, effect, order_price, order_qty,
-                         discretion_price)
+        self._insert_order(market, code, order_type, EnumProto.KOrderDirection_Sell, effect, order_price, order_qty,
+                           discretion_price)
 
     # 撤单委托
     def Cancel(self, order_id: str):
